@@ -4,8 +4,8 @@
 # ** header v3.0
 # This file is a part of the CaosDB Project.
 #
-# Copyright (C) 2021 Henrik tom Wörden
-#               2021 Alexander Schlemmer
+# Copyright (C) 2021-2022 Henrik tom Wörden
+#               2021-2022 Alexander Schlemmer
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -208,18 +208,10 @@ class IdentifiableAdapter(metaclass=ABCMeta):
                 # TODO: how to handle missing values in identifiables
                 #       raise an exception?
                 raise NotImplementedError(
-                    f"RECORD\n{record}\nPROPERTY\n{prop.name}"
+                    f"The following record is missing an identifying property:"
+                    f"RECORD\n{record}\nIdentifying PROPERTY\n{prop.name}"
                 )
             newval = record_prop.value
-            if isinstance(record_prop.value, db.Entity):
-                newval = self.resolve_reference(record_prop.value)
-            elif isinstance(record_prop.value, list):
-                newval = list()
-                for element in record_prop.value:
-                    if isinstance(element, db.Entity):
-                        newval.append(self.resolve_reference(element))
-                    else:
-                        newval.append(element)
             record_prop_new = db.Property(name=record_prop.name,
                                           id=record_prop.id,
                                           description=record_prop.description,
@@ -371,16 +363,13 @@ class LocalStorageIdentifiableAdapter(IdentifiableAdapter):
             # a) prop_record.value has a registered identifiable:
             #      in this case, fetch the identifiable and set the value accordingly
             if isinstance(prop.value, db.Entity):  # lists are not checked here
-                registered = self.get_registered_identifiable(prop.value)
+                otherid = prop_record.value
+                if isinstance(prop_record.value, db.Entity):
+                    otherid = prop_record.value.id
+                if prop.value.id != otherid:
+                    return False
 
-                if registered is None:
-                    raise NotImplementedError("Non-identifiable references cannot"
-                                              " be used as properties in identifiables.")
-
-                raise RuntimeError("The identifiable which is used as property"
-                                   " here has to be inserted first.")
-
-            if prop.value != prop_record.value:
+            elif prop.value != prop_record.value:
                 return False
         return True
 
